@@ -732,6 +732,8 @@ pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
 // sa, Saudi Arabia, .<al-Saudiah>
 pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
 // ru, Russian Federation, .<RF>
@@ -825,7 +827,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 847 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 849 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -884,6 +886,9 @@ pref("network.proxy.autoconfig_url", "");
 pref("network.proxy.autoconfig_retry_interval_min", 5);    // 5 seconds
 pref("network.proxy.autoconfig_retry_interval_max", 300);  // 5 minutes
 
+pref("network.buffer.cache.count", 24);
+pref("network.buffer.cache.size",  4096);
+
 pref("converter.html2txt.structs",          true); // Output structured phrases (strong, em, code, sub, sup, b, i, u)
 pref("converter.html2txt.header_strategy",  1); // 0 = no indention; 1 = indention, increased with header level; 2 = numbering and slight indention
 
@@ -1243,15 +1248,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1662 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 1667 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2086 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2091 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2289 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2294 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2385 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2390 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2388 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2393 "/home/karma/src/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1521,15 +1526,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2660 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2665 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2728 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2733 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2754 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2759 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2774 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2779 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
-//@line 2782 "/home/karma/src/build/modules/libpref/src/init/all.js"
+//@line 2787 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1566,10 +1571,10 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2824 "/home/karma/src/build/modules/libpref/src/init/all.js"
-
 //@line 2829 "/home/karma/src/build/modules/libpref/src/init/all.js"
 
+//@line 2834 "/home/karma/src/build/modules/libpref/src/init/all.js"
+
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
